/*
The sensor outputs provided by the library are the raw
16-bit values obtained by concatenating the 8-bit high and
low accelerometer and gyro data registers. They can be
converted to units of g and dps (degrees per second) using
the conversion factors specified in the datasheet for your
particular device and full scale setting (gain).

Example: An LSM6DS33 gives an accelerometer Z axis reading
of 16276 with its default full scale setting of +/- 2 g. The
LA_So specification in the LSM6DS33 datasheet (page 15)
states a conversion factor of 0.061 mg/LSB (least
significant bit) at this FS setting, so the raw reading of
16276 corresponds to 16276 * 0.061 = 992.8 mg = 0.9928 g.

C.F : https://www.pololu.com/file/0J1087/LSM6DS33.pdf
*/

#include <LSM6.h>

LSM6 imu;

float SetAccelSensibility(){
if (ACCELEROMETER_SENSITIVITY == 2){ return 0.061/1000; }
else if (ACCELEROMETER_SENSITIVITY == 4){ return 0.122/1000; }
else if (ACCELEROMETER_SENSITIVITY == 8){ return 0.244/1000; }
else if (ACCELEROMETER_SENSITIVITY == 16){ return 0.488/1000; }
else{ Serial.println("Mauvaise sensibilité +/- spécifiée. Valeurs typiques : 2/4/8/16"); }
}

float SetGyroSensibility(){
  if (GYROSCOPE_SENSITIVITY == 125){ return static_cast<float>(4.375)/1000; }
  else if (GYROSCOPE_SENSITIVITY == 245){ return static_cast<float>(8.75)/1000; }
  else if (GYROSCOPE_SENSITIVITY == 500){ return static_cast<float>(17.50)/1000; }
  else if (GYROSCOPE_SENSITIVITY == 1000){ return static_cast<float>(35)/1000; }
  else if (GYROSCOPE_SENSITIVITY == 2000){ return static_cast<float>(70)/1000; }
  else{ Serial.println("Mauvaise sensibilité +/- spécifiée. Valeurs typiques : 125"); }
}

float accel_conversion_factor = SetAccelSensibility(); // On passe de mG en G
float gyro_conversion_factor = SetGyroSensibility(); // On passe de mD/S en Degrés/S


void SetupIMU()
{
  if (!imu.init())
  {
    Serial.println("Failed to detect and initialize IMU!");
    while (1);
  }
  imu.enableDefault();
}


void ReadAccel()
{
  accel_readings[0] = imu.a.x*accel_conversion_factor;
  accel_readings[1] = imu.a.y*accel_conversion_factor;
  accel_readings[2] = imu.a.z*accel_conversion_factor;
}

void ReadGyro()
{
  gyro_readings[0] = (imu.g.x-offset_averageX)*gyro_conversion_factor;
  gyro_readings[1] = (imu.g.y-offset_averageY)*gyro_conversion_factor;
  gyro_readings[2] = (imu.g.z-offset_averageZ)*gyro_conversion_factor;
}


void ReadIMU(){
  imu.read();
  ReadAccel();
  ReadGyro();
}
